@@ -14,15 +14,15 @@
 #include "femonservice.h"
 #include "femontools.h"
 
-#if defined(APIVERSNUM) && APIVERSNUM < 10727
-#error "VDR-1.7.27 API version or greater is required!"
+#if defined(APIVERSNUM) && APIVERSNUM < 20000
+#error "VDR-2.0.0 API version or greater is required!"
 #endif
 
 #ifndef GITVERSION
 #define GITVERSION ""
 #endif
 
-static const char VERSION[]       = "1.7.17" GITVERSION;
+static const char VERSION[]       = "2.0.0" GITVERSION;
 static const char DESCRIPTION[]   = trNOOP("DVB Signal Information Monitor (OSD)");
 static const char MAINMENUENTRY[] = trNOOP("Signal Information");
 
@@ -136,7 +136,7 @@ bool cPluginFemon::Service(const char *Id, void *Data)
 {
   if (strcmp(Id,"FemonService-v1.0") == 0) {
      if (Data) {
-        FemonService_v1_0 *data = (FemonService_v1_0*)Data;
+        FemonService_v1_0 *data = reinterpret_cast<FemonService_v1_0*>(Data);
         if (!cDevice::ActualDevice())
            return false;
         cDvbDevice *dev = getDvbDevice(cDevice::ActualDevice());
@@ -318,6 +318,7 @@ cMenuFemonSetup::cMenuFemonSetup(void)
   themes[eFemonThemePearlHD]       = tr("PearlHD");
 
   data = femonConfig;
+  SetMenuCategory(mcSetupPlugins);
   Setup();
 }
 
