@@ -28,13 +28,12 @@ public:
   int skin;
   int theme;
   int position;
+  int downscale;
   int redlimit;
   int greenlimit;
   int updateinterval;
   int analyzestream;
   int calcinterval;
-  int osdheight;
-  int osdoffset;
   int usesvdrp;
   int svdrpport;
   char svdrpip[MaxSvdrpIp + 1]; // must end with additional null
@@ -60,20 +59,21 @@ enum eFemonThemes
   eFemonThemeEgalsTry,
   eFemonThemeDuotone,
   eFemonThemeSilverGreen,
+  eFemonThemePearlHD,
   eFemonThemeMaxNumber
 };
 
 struct cFemonTheme
 {
   int bpp;
-  int clrBackground;
-  int clrTitleBackground;
-  int clrTitleText;
-  int clrActiveText;
-  int clrInactiveText;
-  int clrRed;
-  int clrYellow;
-  int clrGreen;
+  unsigned int clrBackground;
+  unsigned int clrTitleBackground;
+  unsigned int clrTitleText;
+  unsigned int clrActiveText;
+  unsigned int clrInactiveText;
+  unsigned int clrRed;
+  unsigned int clrYellow;
+  unsigned int clrGreen;
 };
 
 extern const cFemonTheme femonTheme[eFemonThemeMaxNumber];
