@@ -9,9 +9,9 @@
 #include <stdlib.h>
 #include <vdr/interface.h>
 #include <vdr/plugin.h>
-#include <femonservice.h>
+#include "femonservice.h"
 
-static const char VERSION[]       = "0.0.4";
+static const char VERSION[]       = "0.0.5";
 static const char DESCRIPTION[]   = "Femon client";
 static const char MAINMENUENTRY[] = "Show frontend statistic on console";
 
