@@ -44,9 +44,17 @@ enum eSymbols {
   SYMBOL_SEVEN,
   SYMBOL_EIGHT,
   SYMBOL_FORMAT_1080,
+  SYMBOL_FORMAT_1080i,
+  SYMBOL_FORMAT_1080p,
   SYMBOL_FORMAT_720,
+  SYMBOL_FORMAT_720i,
+  SYMBOL_FORMAT_720p,
   SYMBOL_FORMAT_576,
+  SYMBOL_FORMAT_576i,
+  SYMBOL_FORMAT_576p,
   SYMBOL_FORMAT_480,
+  SYMBOL_FORMAT_480i,
+  SYMBOL_FORMAT_480p,
   SYMBOL_MAX_COUNT
   };
 
@@ -69,8 +77,8 @@ public:
   ~cFemonSymbolCache();
   void Refresh();
   cBitmap& Get(eSymbols symbolP);
-  int GetSpacing()  { return yFactorM * DEFAULT_SPACING; }
-  int GetRounding() { return yFactorM * DEFAULT_ROUNDING; }
+  int GetSpacing()  { return int(yFactorM * DEFAULT_SPACING);  }
+  int GetRounding() { return int(yFactorM * DEFAULT_ROUNDING); }
 };
 
 extern cFemonSymbolCache femonSymbols;
